Class: Aws::DataPipeline::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DataPipeline::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-datapipeline/client.rb
Overview
An API client for DataPipeline. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DataPipeline::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_pipeline(params = {}) ⇒ Struct
Validates the specified pipeline and starts processing pipeline tasks.
-
#add_tags(params = {}) ⇒ Struct
Adds or modifies tags for the specified pipeline.
-
#create_pipeline(params = {}) ⇒ Types::CreatePipelineOutput
Creates a new, empty pipeline.
-
#deactivate_pipeline(params = {}) ⇒ Struct
Deactivates the specified running pipeline.
-
#delete_pipeline(params = {}) ⇒ Struct
Deletes a pipeline, its pipeline definition, and its run history.
-
#describe_objects(params = {}) ⇒ Types::DescribeObjectsOutput
Gets the object definitions for a set of objects associated with the pipeline.
-
#describe_pipelines(params = {}) ⇒ Types::DescribePipelinesOutput
Retrieves metadata about one or more pipelines.
-
#evaluate_expression(params = {}) ⇒ Types::EvaluateExpressionOutput
Task runners call ‘EvaluateExpression` to evaluate a string in the context of the specified object.
-
#get_pipeline_definition(params = {}) ⇒ Types::GetPipelineDefinitionOutput
Gets the definition of the specified pipeline.
-
#list_pipelines(params = {}) ⇒ Types::ListPipelinesOutput
Lists the pipeline identifiers for all active pipelines that you have permission to access.
-
#poll_for_task(params = {}) ⇒ Types::PollForTaskOutput
Task runners call ‘PollForTask` to receive a task to perform from AWS Data Pipeline.
-
#put_pipeline_definition(params = {}) ⇒ Types::PutPipelineDefinitionOutput
Adds tasks, schedules, and preconditions to the specified pipeline.
-
#query_objects(params = {}) ⇒ Types::QueryObjectsOutput
Queries the specified pipeline for the names of objects that match the specified set of conditions.
-
#remove_tags(params = {}) ⇒ Struct
Removes existing tags from the specified pipeline.
-
#report_task_progress(params = {}) ⇒ Types::ReportTaskProgressOutput
Task runners call ‘ReportTaskProgress` when assigned a task to acknowledge that it has the task.
-
#report_task_runner_heartbeat(params = {}) ⇒ Types::ReportTaskRunnerHeartbeatOutput
Task runners call ‘ReportTaskRunnerHeartbeat` every 15 minutes to indicate that they are operational.
-
#set_status(params = {}) ⇒ Struct
Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline.
-
#set_task_status(params = {}) ⇒ Struct
Task runners call ‘SetTaskStatus` to notify AWS Data Pipeline that a task is completed and provide information about the final status.
-
#validate_pipeline_definition(params = {}) ⇒ Types::ValidatePipelineDefinitionOutput
Validates the specified pipeline definition to ensure that it is well formed and can be run without error.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1494 1495 1496 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1494 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1497 1498 1499 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1497 def errors_module Errors end |
Instance Method Details
#activate_pipeline(params = {}) ⇒ Struct
Validates the specified pipeline and starts processing pipeline tasks. If the pipeline does not pass validation, activation fails.
If you need to pause the pipeline to investigate an issue with a component, such as a data source or script, call DeactivatePipeline.
To activate a finished pipeline, modify the end date for the pipeline and then activate it.
522 523 524 525 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 522 def activate_pipeline(params = {}, = {}) req = build_request(:activate_pipeline, params) req.send_request() end |
#add_tags(params = {}) ⇒ Struct
Adds or modifies tags for the specified pipeline.
553 554 555 556 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 553 def (params = {}, = {}) req = build_request(:add_tags, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1467 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DataPipeline') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-datapipeline' context[:gem_version] = '1.83.0' Seahorse::Client::Request.new(handlers, context) end |
#create_pipeline(params = {}) ⇒ Types::CreatePipelineOutput
Creates a new, empty pipeline. Use PutPipelineDefinition to populate the pipeline.
619 620 621 622 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 619 def create_pipeline(params = {}, = {}) req = build_request(:create_pipeline, params) req.send_request() end |
#deactivate_pipeline(params = {}) ⇒ Struct
Deactivates the specified running pipeline. The pipeline is set to the ‘DEACTIVATING` state until the deactivation process completes.
To resume a deactivated pipeline, use ActivatePipeline. By default, the pipeline resumes from the last completed execution. Optionally, you can specify the date and time to resume the pipeline.
653 654 655 656 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 653 def deactivate_pipeline(params = {}, = {}) req = build_request(:deactivate_pipeline, params) req.send_request() end |
#delete_pipeline(params = {}) ⇒ Struct
Deletes a pipeline, its pipeline definition, and its run history. AWS Data Pipeline attempts to cancel instances associated with the pipeline that are currently being processed by task runners.
Deleting a pipeline cannot be undone. You cannot query or restore a deleted pipeline. To temporarily pause a pipeline instead of deleting it, call SetStatus with the status set to ‘PAUSE` on individual components. Components that are paused by SetStatus can be resumed.
682 683 684 685 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 682 def delete_pipeline(params = {}, = {}) req = build_request(:delete_pipeline, params) req.send_request() end |
#describe_objects(params = {}) ⇒ Types::DescribeObjectsOutput
Gets the object definitions for a set of objects associated with the pipeline. Object definitions are composed of a set of fields that define the properties of the object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
742 743 744 745 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 742 def describe_objects(params = {}, = {}) req = build_request(:describe_objects, params) req.send_request() end |
#describe_pipelines(params = {}) ⇒ Types::DescribePipelinesOutput
Retrieves metadata about one or more pipelines. The information retrieved includes the name of the pipeline, the pipeline identifier, its current state, and the user account that owns the pipeline. Using account credentials, you can retrieve metadata about pipelines that you or your IAM users have created. If you are using an IAM user account, you can retrieve metadata about only those pipelines for which you have read permissions.
To retrieve the full pipeline definition instead of metadata about the pipeline, call GetPipelineDefinition.
791 792 793 794 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 791 def describe_pipelines(params = {}, = {}) req = build_request(:describe_pipelines, params) req.send_request() end |
#evaluate_expression(params = {}) ⇒ Types::EvaluateExpressionOutput
Task runners call ‘EvaluateExpression` to evaluate a string in the context of the specified object. For example, a task runner can evaluate SQL queries stored in Amazon S3.
829 830 831 832 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 829 def evaluate_expression(params = {}, = {}) req = build_request(:evaluate_expression, params) req.send_request() end |
#get_pipeline_definition(params = {}) ⇒ Types::GetPipelineDefinitionOutput
Gets the definition of the specified pipeline. You can call ‘GetPipelineDefinition` to retrieve the pipeline definition that you provided using PutPipelineDefinition.
881 882 883 884 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 881 def get_pipeline_definition(params = {}, = {}) req = build_request(:get_pipeline_definition, params) req.send_request() end |
#list_pipelines(params = {}) ⇒ Types::ListPipelinesOutput
Lists the pipeline identifiers for all active pipelines that you have permission to access.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
921 922 923 924 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 921 def list_pipelines(params = {}, = {}) req = build_request(:list_pipelines, params) req.send_request() end |
#poll_for_task(params = {}) ⇒ Types::PollForTaskOutput
Task runners call ‘PollForTask` to receive a task to perform from AWS Data Pipeline. The task runner specifies which tasks it can perform by setting a value for the `workerGroup` parameter. The task returned can come from any of the pipelines that match the `workerGroup` value passed in by the task runner and that was launched using the IAM user credentials specified by the task runner.
If tasks are ready in the work queue, ‘PollForTask` returns a response immediately. If no tasks are available in the queue, `PollForTask` uses long-polling and holds on to a poll connection for up to a 90 seconds, during which time the first newly scheduled task is handed to the task runner. To accomodate this, set the socket timeout in your task runner to 90 seconds. The task runner should not call `PollForTask` again on the same `workerGroup` until it receives a response, and this can take up to 90 seconds.
998 999 1000 1001 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 998 def poll_for_task(params = {}, = {}) req = build_request(:poll_for_task, params) req.send_request() end |
#put_pipeline_definition(params = {}) ⇒ Types::PutPipelineDefinitionOutput
Adds tasks, schedules, and preconditions to the specified pipeline. You can use ‘PutPipelineDefinition` to populate a new pipeline.
‘PutPipelineDefinition` also validates the configuration as it adds it to the pipeline. Changes to the pipeline are saved unless one of the following three validation errors exists in the pipeline.
-
An object is missing a name or identifier field.
-
A string or reference field is empty.
-
The number of objects in the pipeline exceeds the maximum allowed objects.
-
The pipeline is in a FINISHED state.
Pipeline object definitions are passed to the ‘PutPipelineDefinition` action and returned by the GetPipelineDefinition action.
1090 1091 1092 1093 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1090 def put_pipeline_definition(params = {}, = {}) req = build_request(:put_pipeline_definition, params) req.send_request() end |
#query_objects(params = {}) ⇒ Types::QueryObjectsOutput
Queries the specified pipeline for the names of objects that match the specified set of conditions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1160 1161 1162 1163 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1160 def query_objects(params = {}, = {}) req = build_request(:query_objects, params) req.send_request() end |
#remove_tags(params = {}) ⇒ Struct
Removes existing tags from the specified pipeline.
1186 1187 1188 1189 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1186 def (params = {}, = {}) req = build_request(:remove_tags, params) req.send_request() end |
#report_task_progress(params = {}) ⇒ Types::ReportTaskProgressOutput
Task runners call ‘ReportTaskProgress` when assigned a task to acknowledge that it has the task. If the web service does not receive this acknowledgement within 2 minutes, it assigns the task in a subsequent PollForTask call. After this initial acknowledgement, the task runner only needs to report progress every 15 minutes to maintain its ownership of the task. You can change this reporting time from 15 minutes by specifying a `reportProgressTimeout` field in your pipeline.
If a task runner does not report its status after 5 minutes, AWS Data Pipeline assumes that the task runner is unable to process the task and reassigns the task in a subsequent response to PollForTask. Task runners should call ‘ReportTaskProgress` every 60 seconds.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1238 def report_task_progress(params = {}, = {}) req = build_request(:report_task_progress, params) req.send_request() end |
#report_task_runner_heartbeat(params = {}) ⇒ Types::ReportTaskRunnerHeartbeatOutput
Task runners call ‘ReportTaskRunnerHeartbeat` every 15 minutes to indicate that they are operational. If the AWS Data Pipeline Task Runner is launched on a resource managed by AWS Data Pipeline, the web service can use this call to detect when the task runner application has failed and restart a new instance.
1287 1288 1289 1290 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1287 def report_task_runner_heartbeat(params = {}, = {}) req = build_request(:report_task_runner_heartbeat, params) req.send_request() end |
#set_status(params = {}) ⇒ Struct
Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline. This update might not occur immediately, but is eventually consistent. The status that can be set depends on the type of object (for example, DataNode or Activity). You cannot perform this operation on ‘FINISHED` pipelines and attempting to do so returns `InvalidRequestException`.
1325 1326 1327 1328 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1325 def set_status(params = {}, = {}) req = build_request(:set_status, params) req.send_request() end |
#set_task_status(params = {}) ⇒ Struct
Task runners call ‘SetTaskStatus` to notify AWS Data Pipeline that a task is completed and provide information about the final status. A task runner makes this call regardless of whether the task was sucessful. A task runner does not need to call `SetTaskStatus` for tasks that are canceled by the web service during a call to ReportTaskProgress.
1379 1380 1381 1382 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1379 def set_task_status(params = {}, = {}) req = build_request(:set_task_status, params) req.send_request() end |
#validate_pipeline_definition(params = {}) ⇒ Types::ValidatePipelineDefinitionOutput
Validates the specified pipeline definition to ensure that it is well formed and can be run without error.
1458 1459 1460 1461 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1458 def validate_pipeline_definition(params = {}, = {}) req = build_request(:validate_pipeline_definition, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1487 1488 1489 |
# File 'lib/aws-sdk-datapipeline/client.rb', line 1487 def waiter_names [] end |